SystemOrganization addCategory: #ConfigurationOfComplex!

Object subclass: #ConfigurationOfComplex
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfComplex'!

!ConfigurationOfComplex class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:09'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfComplex class methodsFor: 'private' stamp: 'nice 11/16/2011 23:15'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfComplex class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:24'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfComplex class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:24'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfComplex class methodsFor: 'private' stamp: 'nice 11/16/2011 23:11'!
ensureMetacello
	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfComplex class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfComplex class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:14'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfComplex class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfComplex class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfComplex class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfComplex class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:22'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfComplex class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:14'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfComplex class methodsFor: 'accessing' stamp: 'nice 11/16/2011 23:09'!
project
	^self new project! !

!ConfigurationOfComplex class methodsFor: 'unloading metacello' stamp: 'nice 11/16/2011 23:15'!
unloadMetacello
	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfComplex class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:23'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- latest mcz files for 1.0.4'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfComplex class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:09'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfComplex methodsFor: 'baselines' stamp: 'nice 11/16/2011 23:49'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('');
			group: 'Tests' with: #('')	].
	spec for: #'squeak' do: [ ].
	spec for: #'pharo' do: [
		spec repository: 'http://www.squeaksource.com/Complex'.
		spec 
			package: 'Math-Complex';
			package: 'Math-ComplexTests' with: [
				spec requires: #('Math-Complex' )].
		spec
			group: 'Core' with: #('Math-Complex');
			group: 'Tests' with: #('Math-ComplexTests')	].! !

!ConfigurationOfComplex methodsFor: 'symbolic versions' stamp: 'nice 11/16/2011 23:01'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'! !

!ConfigurationOfComplex methodsFor: 'accessing' stamp: 'nice 11/16/2011 23:27'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		"Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
			versionString := cl current version.
			((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
				ifTrue: [ projectAttributes := projectAttributes, #() ] ]."
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfComplex methodsFor: 'symbolic versions' stamp: 'nice 11/16/2011 23:01'!
stable: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'! !

!ConfigurationOfComplex methodsFor: 'versions' stamp: 'nice 11/16/2011 23:16'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'initial version'.
		spec author: 'nice'.
		spec timestamp: '11/16/2011 23:03'.].
		spec for: #squeak do:[ ].
		spec for: #pharo do:[
			spec
			package: 'Math-Complex' with: 'Math-Complex-nice.2';
			package: 'Math-ComplexTests' with: 'Math-ComplexTests-nice.2'. ].
! !
